km3pipe.db.StreamDS
===================

.. currentmodule:: km3pipe.db

.. autoclass:: StreamDS

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StreamDS.__init__
      ~StreamDS.get
      ~StreamDS.help
      ~StreamDS.mandatory_selectors
      ~StreamDS.optional_selectors
      ~StreamDS.print_streams
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StreamDS.streams
   
   